TXDeviceManager class

Device management

Constructors

TXDeviceManager(dynamic channel)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

enableCameraAutoFocus(bool enable) → Future<int?>
Set whether to enable the automatic recognition of face position (supports only the Android and iOS platforms)
enableCameraTorch(bool enable) → Future<int?>
Enable/Disable flash (supports only the Android and iOS platforms)
getApplicationMuteState() → Future<bool?>
Get the mute status of the current process in the Windows system volume mixer (supports only the Windows platform)
getApplicationPlayVolume() → Future<int?>
Get the volume of the current process in the Windows system volume mixer (supports only the Windows platform)
getCameraZoomMaxRatio() → Future<double?>
Get the camera zoom factor (supports only the Android and iOS platforms)
getCurrentDevice(int type) → Future<Map?>
Get the currently used device (Support for macOS, Windows and web platforms)
getCurrentDeviceMute(int type) → Future<bool?>
Query the mute status of the current device (Support for macOS and Windows platforms)
getCurrentDeviceVolume(int type) → Future<int?>
Get the volume of the current device (Support for macOS and Windows platforms)
getDevicesList(int type) → Future<Map?>
Get the list of devices (Support for macOS, Windows and web platforms)
isAutoFocusEnabled() → Future<bool?>
Query whether the device supports automatic recognition of face position (supports only the Android and iOS platforms)
isFrontCamera() → Future<bool?>
Set whether to use the front camera (supports only the Android and iOS platforms)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setApplicationMuteState(bool bMute) → Future<int?>
Set the mute status of the current process in the Windows system volume mixer (supports only the Windows platform)
setApplicationPlayVolume(int volume) → Future<int?>
Set the volume of the current process in the Windows system volume mixer (supports only the Windows platform)
setAudioRoute(int route) → Future<int?>
Set audio route, i.e., earpiece at the top or speaker at the bottom (supports only the Android and iOS platforms)
setCameraFocusPosition(int x, int y) → Future<void>
Set camera focus (supports only the Android and iOS platforms)
setCameraZoomRatio(double value) → Future<int?>
Set the zoom factor (focal length) of camera (supports only the Android and iOS platforms)
setCurrentDevice(int type, String deviceId) → Future<int?>
Specify the current device (Support for macOS, Windows and web platforms)
setCurrentDeviceMute(int type, bool mute) → Future<int?>
Set the mute status of the current device (Support for macOS and Windows platforms)
setCurrentDeviceVolume(int type, int volume) → Future<int?>
Set the volume of the current device (Support for macOS and Windows platforms)
setSystemVolumeType(int type) → Future<int?>
Set the system volume type used in call (supports only the Android and iOS platforms)
startMicDeviceTest(int interval) → Future<int?>
Start mic test (Support for macOS and Windows platforms)
startSpeakerDeviceTest(String filePath) → Future<int?>
Start speaker test (Support for macOS and Windows platforms)
stopMicDeviceTest() → Future<int?>
Stop mic test (Support for macOS and Windows platforms)
stopSpeakerDeviceTest() → Future<int?>
Stop speaker test (Support for macOS and Windows platforms)
switchCamera(bool isFrontCamera) → Future<int?>
Switch camera (supports only the Android and iOS platforms)
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited