V2TXLiveFlutterResult class

Constructors

V2TXLiveFlutterResult()

Properties

hashCode → V2TXLiveCode
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

boolValue<T>(T? result) → bool?
convert bool
doubleValue<T>(T? result) → double?
convert double
intValue<T>(T? result) → int?
convert int
mapValue<T>(T? result) → Map?
convert Map
v2TXLiveCode<T>(T? result) → int?
covert V2TXLiveCode